@@ -98,6 +98,7 @@ class Project(object):
         self.filename = self.model_name + ".xml"
         self.backend = "local_smart" #this is just the default.
         self.compile_options = ""
+        self.error_list = []
 
         # Quick'n'dirty define access functions
         # needed in context with GTKProject
@@ -198,6 +199,10 @@ class Project(object):
                 kwargs.pop('actions')
             process = Process(**kwargs)
             self.process_list.append(process)
+
+            if 'name' in kwargs:
+                if len(kwargs['name']) > 30:
+                    self.error_list.append(tuple(("Process Name", kwargs['name'], "Process name should not be longer than 30 characters, otherwise the Fortran compiler may raise errors")))
         return process
 
     def parse_process(self, string):
@@ -565,8 +570,13 @@ class Project(object):
 
                 process.name = short_name
 
-        with open('abbreviations_{}.dat'.format(self.meta.model_name), 'w') as outfile:
-            outfile.write(pprint.pformat(stub_map))
+        try: #Aug 14th 2022: A. Savara does not understand what the 'abbreviations_' is for. It was causing problems with a fresh installation on an Ubuntu 20.04 Virtual Machine with python 3.10, but removing 'abbreviations_' allowed kmcos to proceed normally.
+	        with open('abbreviations_{}.dat'.format(self.meta.model_name), 'w') as outfile:
+        	    outfile.write(pprint.pformat(stub_map))
+        except:
+	        with open('{}.dat'.format(self.meta.model_name), 'w') as outfile:
+        	    outfile.write(pprint.pformat(stub_map))        	
+        	    
 
     def clear_model(self, model_name='', backend=''):
         if backend=='': backend = self.backend
@@ -592,6 +602,10 @@ class Project(object):
             raise UserWarning('Cannot export to file suffix %s' %
                               os.path.splitext(self.filename)[-1])
 
+        #If there are errors with the model object, then write the list of errors to a .log file
+        if len(self.error_list) > 0:
+            np.savetxt(self.model_name+"__build.log", self.error_list, delimiter=", ", fmt="%s", header = "Type, Name, Message")
+
 
     def save(self, filename="", validate=True):
         self.save_model(filename, validate)
